cgexplore.analysis.GeomMeasure
==============================

.. currentmodule:: cgexplore.analysis

.. autoclass:: GeomMeasure
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~GeomMeasure.calculate_angles
      ~GeomMeasure.calculate_bonds
      ~GeomMeasure.calculate_max_diameter
      ~GeomMeasure.calculate_min_distance
      ~GeomMeasure.calculate_minb2b
      ~GeomMeasure.calculate_radius_gyration
      ~GeomMeasure.calculate_torsions
   
   

   
   
   